==> anwiba-commons-json-1.0.58-sources.jar: net/anwiba/commons/json/schema/v1_0/IntegerProperty.java <==
//Copyright (c) 2016 by Andreas W. Bartels (bartels@anwiba.de)
package net.anwiba.commons.json.schema.v1_0;

import com.fasterxml.jackson.annotation.JsonProperty;

public class IntegerProperty
    extends Property
{

    private final String type = "integer";
    private Integer _default = null;
    private String format = null;
    private Integer maxLength = null;
    private Integer minimum = null;
    private Integer maximum = null;
    private Integer exclusiveMinimum = null;
    private Integer exclusiveMaximum = null;
    private Integer divisibleBy = null;
    private Integer[] _enum = null;

    @JsonProperty("type")
    public void setType(final String type) {
    }

    @JsonProperty("type")
    public String getType() {
        return this.type;
    }

    @JsonProperty("default")
    public void setDefault(final Integer _default) {
        this._default = _default;
    }

    @JsonProperty("default")
    public Integer getDefault() {
        return this._default;
    }

    @JsonProperty("format")
    public void setFormat(final String format) {
        this.format = format;
    }

    @JsonProperty("format")
    public String getFormat() {
        return this.format;
    }

    @JsonProperty("maxLength")
    public void setMaxLength(final Integer maxLength) {
        this.maxLength = maxLength;
    }

    @JsonProperty("maxLength")
    public Integer getMaxLength() {
        return this.maxLength;
    }

    @JsonProperty("minimum")
    public void setMinimum(final Integer minimum) {
        this.minimum = minimum;
    }

    @JsonProperty("minimum")
    public Integer getMinimum() {
        return this.minimum;
    }

    @JsonProperty("maximum")
    public void setMaximum(final Integer maximum) {
        this.maximum = maximum;
    }

    @JsonProperty("maximum")
    public Integer getMaximum() {
        return this.maximum;
    }

    @JsonProperty("exclusiveMinimum")
    public void setExclusiveMinimum(final Integer exclusiveMinimum) {
        this.exclusiveMinimum = exclusiveMinimum;
    }

    @JsonProperty("exclusiveMinimum")
    public Integer getExclusiveMinimum() {
        return this.exclusiveMinimum;
    }

    @JsonProperty("exclusiveMaximum")
    public void setExclusiveMaximum(final Integer exclusiveMaximum) {
        this.exclusiveMaximum = exclusiveMaximum;
    }

    @JsonProperty("exclusiveMaximum")
    public Integer getExclusiveMaximum() {
        return this.exclusiveMaximum;
    }

    @JsonProperty("divisibleBy")
    public void setDivisibleBy(final Integer divisibleBy) {
        this.divisibleBy = divisibleBy;
    }

    @JsonProperty("divisibleBy")
    public Integer getDivisibleBy() {
        return this.divisibleBy;
    }

    @JsonProperty("enum")
    public void setEnum(final Integer[] _enum) {
        this._enum = _enum;
    }

    @JsonProperty("enum")
    public Integer[] getEnum() {
        return this._enum;
    }

}

==> anwiba-commons-json-1.0.76-sources.jar: net/anwiba/commons/json/schema/v1_0/IntegerProperty.java <==
//Copyright (c) 2016 by Andreas W. Bartels (bartels@anwiba.de)
package net.anwiba.commons.json.schema.v1_0;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;

public class IntegerProperty
    extends Property
{

    private final String type = "integer";
    private Integer _default = null;
    private String format = null;
    private Integer maxLength = null;
    private Integer minimum = null;
    private Integer maximum = null;
    private Integer exclusiveMinimum = null;
    private Integer exclusiveMaximum = null;
    private Integer divisibleBy = null;
    private Integer[] _enum = null;

    @JsonIgnore
    public void setType(final String type) {
    }

    @JsonIgnore
    public String getType() {
        return this.type;
    }

    @JsonProperty("default")
    public void setDefault(final Integer _default) {
        this._default = _default;
    }

    @JsonProperty("default")
    public Integer getDefault() {
        return this._default;
    }

    @JsonProperty("format")
    public void setFormat(final String format) {
        this.format = format;
    }

    @JsonProperty("format")
    public String getFormat() {
        return this.format;
    }

    @JsonProperty("maxLength")
    public void setMaxLength(final Integer maxLength) {
        this.maxLength = maxLength;
    }

    @JsonProperty("maxLength")
    public Integer getMaxLength() {
        return this.maxLength;
    }

    @JsonProperty("minimum")
    public void setMinimum(final Integer minimum) {
        this.minimum = minimum;
    }

    @JsonProperty("minimum")
    public Integer getMinimum() {
        return this.minimum;
    }

    @JsonProperty("maximum")
    public void setMaximum(final Integer maximum) {
        this.maximum = maximum;
    }

    @JsonProperty("maximum")
    public Integer getMaximum() {
        return this.maximum;
    }

    @JsonProperty("exclusiveMinimum")
    public void setExclusiveMinimum(final Integer exclusiveMinimum) {
        this.exclusiveMinimum = exclusiveMinimum;
    }

    @JsonProperty("exclusiveMinimum")
    public Integer getExclusiveMinimum() {
        return this.exclusiveMinimum;
    }

    @JsonProperty("exclusiveMaximum")
    public void setExclusiveMaximum(final Integer exclusiveMaximum) {
        this.exclusiveMaximum = exclusiveMaximum;
    }

    @JsonProperty("exclusiveMaximum")
    public Integer getExclusiveMaximum() {
        return this.exclusiveMaximum;
    }

    @JsonProperty("divisibleBy")
    public void setDivisibleBy(final Integer divisibleBy) {
        this.divisibleBy = divisibleBy;
    }

    @JsonProperty("divisibleBy")
    public Integer getDivisibleBy() {
        return this.divisibleBy;
    }

    @JsonProperty("enum")
    public void setEnum(final Integer[] _enum) {
        this._enum = _enum;
    }

    @JsonProperty("enum")
    public Integer[] getEnum() {
        return this._enum;
    }

}
